@@ -53,8 +53,6 @@ class ConsumerJob(Thread):
             self.__listen__()
         except KafkaException as e:
             self.logger.exception( f"Exception from topic, when handling another: {self.__conf__.topic} : {type(e)} {e}" )
-        except:
-            self.logger.exception( f"Exception from topic, when handling another: {self.__conf__.topic}" )
           
     def stop(self):
         self.logger.info( f"Stopping consumer, topic: {self.__conf__.topic}" )
